@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10797 2018-03-01 02:31:02Z David $
+# $Id: views.py 11560 2019-05-17 04:24:58Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-01 10:31:02 +0800 (週四, 01 三月 2018) $
-# $Revision: 10797 $
+# $Author: Andy $
+# $Date: 2019-05-17 12:24:58 +0800 (週五, 17 五月 2019) $
+# $Revision: 11560 $
 
 import base64
 from datetime import datetime
@@ -60,10 +60,10 @@ logger = createDebugLogger('TheophrastusIntegrationApi', settings.API_LOG)
 
 class TokenGenerator(object):
     def __init__(self, secretKey):
-        self.encryptor = Encryptor(secretKey)
+        self.encryptor = Encryptor(str(secretKey))
 
     def getToken(self, content):
-        return base64.urlsafe_b64encode(self.encryptor.encrypt(content))
+        return base64.urlsafe_b64encode(self.encryptor.encrypt(str(content)))
 
     def getContent(self, token):
         return self.encryptor.decrypt(base64.urlsafe_b64decode(token))
@@ -379,7 +379,7 @@ def getTotalData(request, groupId):
 
     conditions = {'newsletter__id__in': newsletterIds}
     response = getStatisticsTotalData(
-        request.GET, subscriberCount, 
+        request.GET, subscriberCount,
         testSubscriberCount, conditions)
 
     return response
